=========
Reference
=========

.. toctree::

   reference_constants/index
   reference_containers/index
   reference_events/index
   reference_best_response/index
   reference_tau_vector/index
   reference_strategies/index
   reference_profiles/index
   reference_iterables/index
   reference_random_factories/index
   reference_meta_monte_carlo_fictitious_play/index
   reference_meta_binary_plots/index
   reference_meta_ternary_plots/index
   reference_meta_misc/index
   reference_utils/index
